@@ -1,8 +1,8 @@
 #!/bin/sh
 ##
 ##  OSSP svs -- Stupid/Silly/Simple Versioning System
-##  Copyright (c) 2003-2004 Ralf S. Engelschall <rse@engelschall.com>
-##  Copyright (c) 2003-2004 The OSSP Project <http://www.ossp.org/>
+##  Copyright (c) 2003-2005 Ralf S. Engelschall <rse@engelschall.com>
+##  Copyright (c) 2003-2005 The OSSP Project <http://www.ossp.org/>
 ##
 ##  This file is part of OSSP svs, a stupid/silly/simple versioning
 ##  system which can found at http://www.ossp.org/pkg/tool/svs/
@@ -33,6 +33,7 @@ if [ $# -eq 0 ]; then
     echo "Usage: svs vi <file> [...]"
     echo "Usage: svs diff [<file>|<dir> [...]]"
     echo "Usage: svs backout [<file>|<dir> [...]]"
+    echo "Usage: svs status [<file>|<dir> [...]]"
     exit 1
 fi
 
@@ -57,7 +58,11 @@ case "$cmd" in
 
             #   edit file
             chmod u+w $file
-            ${EDITOR-vi} $file
+            if [ ".${EDITOR-vi}" = .vim -a -f $file.rej ]; then
+                ${EDITOR-vi} -o2 $file $file.rej
+            else
+                ${EDITOR-vi} $file
+            fi
 
             #   check for editing results
             if cmp $file.orig $file >/dev/null 2>&1; then
@@ -70,6 +75,9 @@ case "$cmd" in
                 rm -f $file.orig
             else
                 echo "svs: changes made (preserving original)"
+                if [ -f $file.rej ]; then
+                    rm -f $file.rej
+                fi
             fi
         done
         ;;
@@ -86,7 +94,7 @@ case "$cmd" in
         files=""
         for file in "$@"; do
             if [ -d $file ]; then
-                for f in `find $file -type f -name "*.orig" -print`; do
+                for f in `find $file -type f -name "*.orig" -print | sort`; do
                     files="$files $f"
                 done
             elif [ -f $file ]; then
@@ -136,7 +144,7 @@ case "$cmd" in
         files=""
         for file in "$@"; do
             if [ -d $file ]; then
-                for f in `find $file -type f -name "*.orig" -print`; do
+                for f in `find $file -type f -name "*.orig" -print | sort`; do
                     files="$files $f"
                 done
             elif [ -f $file ]; then
@@ -173,6 +181,43 @@ case "$cmd" in
             fi
         done
         ;;
+
+    s|st|sta|stat|statu|status )
+        ##
+        ##  CHANGE STATUS
+        ##
+
+        #   determine file list
+        if [ $# -eq 0 ]; then
+            set -- .
+        fi
+        files=""
+        for file in "$@"; do
+            if [ -d $file ]; then
+                for f in `find $file -type f \( -name "*.orig" -or -name "*.rej" \) -print | sort`; do
+                    files="$files $f"
+                done
+            elif [ -f $file ]; then
+                files="$files $file"
+            else
+                echo "svs:ERROR: \"$file\" neither regular file nor directory" 1>&2
+                exit 1
+            fi
+        done
+
+        #   show status on files
+        for file in $files; do
+            file=`echo "$file" | sed -e 's;^\./;;' -e 's;/\./;/;g' -e 's;\([^/][^/]*\)/\.\.;;g' -e 's;//*;/;g'`
+            base=`echo "$file" | sed -e 's;\.orig$;;' -e 's;\.rej$;;'`
+            prefix="?"
+            case "$file" in
+                *.orig ) prefix="M" ;;
+                *.rej  ) prefix="C" ;;
+            esac
+            echo "$prefix $base"
+        done
+        ;;
+
     * )
         echo "svs:ERROR: invalid command \"$cmd\"" 1>&2
         exit 1
